@@ -8,27 +8,27 @@
 #' @param appDir Directory containing application. Defaults to current working
 #'   directory.
 #' @return Returns a data frame listing the package
-#'   dependencies detected for the application: \tabular{ll}{ \code{package}
-#'   \tab Name of package \cr \code{version} \tab Version of package\cr }
+#'   dependencies detected for the application: \tabular{ll}{ `package`
+#'   \tab Name of package \cr `version` \tab Version of package\cr }
 #' @details Dependencies are determined by parsing application source code and
-#'   looking for calls to \code{library}, \code{require}, \code{::}, and
-#'   \code{:::}.
+#'   looking for calls to `library`, `require`, `::`, and
+#'   `:::`.
 #'
-#'   Recursive dependencies are detected by examining the \code{Depends},
-#'   \code{Imports}, and \code{LinkingTo} fields of the packages immediately
+#'   Recursive dependencies are detected by examining the `Depends`,
+#'   `Imports`, and `LinkingTo` fields of the packages immediately
 #'   dependend on by the application.
 #'
-#' @note Since the \code{Suggests} field is not included when determining
+#' @note Since the `Suggests` field is not included when determining
 #'   recursive dependencies of packages, it's possible that not every package
 #'   required to run your application will be detected.
 #'
 #'   In this case, you can force a package to be included dependency by
-#'   inserting call(s) to \code{require} within your source directory. This code
+#'   inserting call(s) to `require` within your source directory. This code
 #'   need not actually execute, for example you could create a standalone file
-#'   named \code{dependencies.R} with the following code: \cr \cr
-#'   \code{require(xts)} \cr \code{require(colorspace)} \cr
+#'   named `dependencies.R` with the following code: \cr \cr
+#'   `require(xts)` \cr `require(colorspace)` \cr
 #'
-#'   This will force the \code{xts} and \code{colorspace} packages to be
+#'   This will force the `xts` and `colorspace` packages to be
 #'   installed along with the rest of your application when it is deployed.
 #' @examples
 #' \dontrun{
@@ -39,7 +39,7 @@
 #' # dependencies for an app in another directory
 #' appDependencies("~/projects/shiny/app1")
 #' }
-#' @seealso \link[rsconnect:rsconnectPackages]{Using Packages with rsconnect}
+#' @seealso [rsconnectPackages](Using Packages with rsconnect)
 #' @export
 appDependencies <- function(appDir = getwd(), appFiles=NULL) {
   # if the list of files wasn't specified, generate it
@@ -47,6 +47,7 @@ appDependencies <- function(appDir = getwd(), appFiles=NULL) {
     appFiles <- bundleFiles(appDir)
   }
   bundleDir <- bundleAppDir(appDir, appFiles)
+  on.exit(unlink(bundleDir, recursive = TRUE), add = TRUE)
   deps <- snapshotDependencies(bundleDir)
   data.frame(package = deps[,"Package"],
              version = deps[,"Version"],
