@@ -617,6 +617,16 @@ httpRCurl <- function(protocol,
   # get list of HTTP response headers
   headers <- headerGatherer$value()
 
+  # deduce status. we do this *before* lowercase conversion, as it is possible
+  # for both "Status" and "status" headers to exist
+  status <- 200
+  statuses <- headers[names(headers) == "status"]   # find status header
+  statuses <- statuses[grepl("^\\d+$", statuses)]   # ensure fully numeric
+  if (length(statuses) > 0) {
+    # we found a numeric status header
+    status <- as.integer(statuses[[1]])
+  }
+
   # lowercase all header names for normalization; HTTP/2 uses lowercase headers
   # by default but they're typically capitalized in HTTP/1
   names(headers) <- tolower(names(headers))
@@ -653,7 +663,7 @@ httpRCurl <- function(protocol,
                   port     = port,
                   method   = method,
                   path     = path),
-       status = as.integer(headers[["status"]]),
+       status = status,
        location = location,
        contentType = contentType,
        content = contentValue)
